@@ -1,3 +1,17 @@
+# Copyright 2022 Cisco Systems, Inc. and/or its affiliates.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import importlib.metadata
 import pathlib
 from typing import Optional
@@ -21,7 +35,7 @@ def __get_version() -> Optional[str]:
 
 
 __version__ = __get_version() or "0.0.0"
-__cryptonym__ = "subtle rhapsody"
+__cryptonym__ = "genesis"
 
 # Add the devtools debug() function to builtins if available
 import builtins
